# CommonSense QA2

Sample generated by `lime init dataset --simple`

#### meta
 - max_tokens: 10

#### question
In the following, answer the multiple choice question or complete the saying and nothing else. Use commonsense and traditional folk wisdom to answer the question.
|EVAL-ENDCHAR|

## Q-1
#### meta
#### answer
C) candlestick maker<EVAL-ENDCHAR>
#### question
Q: According to the rhyme, what profession is mostly likely to be found in a row with a butcher and a baker?
A) omellette maker
B) quaker
C) candlestick maker
<EVAL-ENDCHAR>

## Q-2
#### meta
#### question
Q: What is the largest planet in the solar system?
A) Jupiter
B) Saturn
C) Uranus
#### answer
B) Saturn<EVAL-ENDCHAR>